# elan-scissors

Cut ELAN audio into snippets. You may need to [install an audio library usable by pydub](https://github.com/jiaaro/pydub#getting-ffmpeg-set-up).
Usage:

`elanscissors <SRC> <TARGET>`, where `SRC` is a flextext file and `TARGET` a wav file.

Documentation: https://elan-scissors.readthedocs.io

![License](https://img.shields.io/github/license/fmatter/elan-scissors)
[![Documentation Status](https://readthedocs.org/projects/elan-scissors/badge/?version=latest)](https://elan-scissors.readthedocs.io/en/latest/?badge=latest)
[![Linting](https://img.shields.io/github/workflow/status/fmatter/elan-scissors/lint?label=linting)](https://github.com/fmatter/elan-scissors/actions/workflows/lint.yml)
[![PyPI](https://img.shields.io/pypi/v/elan-scissors.svg)](https://pypi.org/project/elan-scissors)
![Versions](https://img.shields.io/pypi/pyversions/elan-scissors)
